@@ -5,13 +5,48 @@ os.environ['LANGUAGE'] = 'zh_CN.UTF-8'
 import sys
 import typer
 import builtins
+
+import logging
+from astropy.logger import AstropyLogger
+
+logging.setLoggerClass(AstropyLogger)
+logging.getLogger('astroquery').setLevel(logging.INFO)
+
+# Monkey patch astroquery DummyLogger: add getEffectiveLevel to avoid AttributeError
+try:
+    import importlib
+    aq_logger_mod = importlib.import_module("astroquery.logger")
+    if hasattr(aq_logger_mod, "DummyLogger"):
+        def _dummy_getEffectiveLevel(self):
+            return logging.INFO
+        aq_logger_mod.DummyLogger.getEffectiveLevel = _dummy_getEffectiveLevel
+except Exception:
+    pass
+# Monkey patch for astroquery.logger._init_log to support astropy >= 6.0
+try:
+    import importlib
+    from astropy.logger import AstropyLogger
+    aq_logger_mod = importlib.import_module("astroquery.logger")
+
+    def _new_init_log():
+        """Initializes the log, including the log levels and log writer."""
+        log = AstropyLogger('astroquery')
+        # log._set_defaults() # This line is removed as it's deprecated in astropy 6.0
+        return log
+
+    if hasattr(aq_logger_mod, '_init_log'):
+        aq_logger_mod._init_log = _new_init_log
+
+except Exception:
+    pass
 from io import StringIO
 from contextlib import redirect_stdout
 from astropy.config import get_config_dir, get_config
-from rich.console import Console # Import Console
-from rich.text import Text # Import Text
+from rich.console import Console # Re-import Console if needed for other parts
+from rich.text import Text # Re-import Text if needed for other parts
 import re # Import re
 import logging # Import logging
+import shutil # Re-import shutil if needed for other parts
 
 # Suppress astroquery log messages globally (moved to __init__.py for earlier execution)
 # Monkey patch for astroquery.logger._init_log (moved to __init__.py for earlier execution)
@@ -34,13 +69,12 @@ def save_default_lang(lang):
 def load_default_lang():
     return config.get_language()
 
-
 app = typer.Typer(
     name="aqc",
-    help=i18n._("Astroquery CLI"),
+    help=builtins._("Astroquery CLI"),
     invoke_without_command=True,
     no_args_is_help=False,
-    add_completion=True,
+    add_completion=False, # Set to False to remove global completion commands
     context_settings={"help_option_names": ["-h", "--help"]},
 )
 
@@ -51,26 +85,34 @@ def setup_subcommands():
 
     # Import all subcommands
     from .modules import (
-        simbad_cli, alma_cli, esasky_cli, gaia_cli, irsa_cli, irsa_dust_cli,
-        jplhorizons_cli, jplsbdb_cli, mast_cli, nasa_ads_cli, ned_cli,
-        splatalogue_cli, vizier_cli
+        simbad_cli, alma_cli, esasky_cli, gaia_cli, irsa_cli, jpl_cli,
+        mast_cli, ads_cli, ned_cli, splatalogue_cli, vizier_cli,
+        heasarc_cli, sdss_cli, eso_cli, nist_cli, exoplanet_cli
     )
     # Restore astroquery log level after import
     logging.getLogger('astroquery').setLevel(logging.NOTSET)
 
-    app.add_typer(alma_cli.get_app(), name="alma")
-    app.add_typer(esasky_cli.get_app(), name="esasky")
-    app.add_typer(gaia_cli.get_app(), name="gaia")
-    app.add_typer(irsa_cli.get_app(), name="irsa")
-    app.add_typer(irsa_dust_cli.get_app(), name="irsa_dust")
-    app.add_typer(jplhorizons_cli.get_app(), name="jplhorizons")
-    app.add_typer(jplsbdb_cli.get_app(), name="jplsbdb")
     app.add_typer(mast_cli.get_app(), name="mast")
-    app.add_typer(nasa_ads_cli.get_app(), name="nasa_ads")
+    app.add_typer(vizier_cli.get_app(), name="vizier", help=builtins._("Query the VizieR astronomical catalog database. (viz)"))
+    app.add_typer(vizier_cli.get_app(), name="viz") # Alias for vizier
+    app.add_typer(simbad_cli.get_app(), name="simbad", help=builtins._("Query the SIMBAD astronomical database. (sim)"))
+    app.add_typer(simbad_cli.get_app(), name="sim") # Alias for simbad
+    app.add_typer(jpl_cli.get_app(), name="jpl") # Updated for jpl
+    app.add_typer(exoplanet_cli.get_app(), name="exoplanet", help=builtins._("Query the NASA Exoplanet Archive. (exo)"))
+    app.add_typer(exoplanet_cli.get_app(), name="exo") # Alias for exoplanet
+    app.add_typer(heasarc_cli.get_app(), name="heasarc", help=builtins._("Query the HEASARC database. (hea)"))
+    app.add_typer(heasarc_cli.get_app(), name="hea") # Alias for heasarc
+    app.add_typer(gaia_cli.get_app(), name="gaia")
+    app.add_typer(alma_cli.get_app(), name="alma")
+    app.add_typer(irsa_cli.get_app(), name="irsa")
+    app.add_typer(sdss_cli.get_app(builtins._), name="sdss")
     app.add_typer(ned_cli.get_app(), name="ned")
-    app.add_typer(simbad_cli.get_app(), name="simbad")
-    app.add_typer(splatalogue_cli.get_app(), name="splatalogue")
-    app.add_typer(vizier_cli.get_app(), name="vizier")
+    app.add_typer(eso_cli.get_app(), name="eso")
+    app.add_typer(esasky_cli.get_app(), name="esasky")
+    app.add_typer(nist_cli.get_app(builtins._), name="nist")
+    app.add_typer(splatalogue_cli.get_app(), name="splatalogue", help=builtins._("Query the Splatalogue spectral line database. (spl)"))
+    app.add_typer(splatalogue_cli.get_app(), name="spl") # Alias for splatalogue
+    app.add_typer(ads_cli.get_app(), name="ads")
 
 @app.callback()
 def main_callback(
@@ -79,7 +121,7 @@ def main_callback(
         None,
         "-l",
         "--lang",
-        help=i18n._("Set the language for output messages (e.g., 'en', 'zh'). Affects help texts and outputs."),
+        help=builtins._("Set the language for output messages (e.g., 'en', 'zh'). Affects help texts and outputs."),
         is_eager=True,
         envvar="AQC_LANG",
         show_default=False
@@ -88,26 +130,26 @@ def main_callback(
         False,
         "-p",
         "--ping",
-        help=i18n._("Test connectivity to major services (only available at top-level command).")
+        help=builtins._("Test connectivity to major services (only available at top-level command).")
     ),
     field: bool = typer.Option(
         False,
         "-f",
         "--field",
-        help=i18n._("Test field validity for modules (only available at top-level command).")
+        help=builtins._("Test field validity for modules (only available at top-level command).")
     ),
     debug: bool = typer.Option(
         False,
         "-d",
         "--debug",
-        help=i18n._("Enable debug mode with verbose output."),
+        help=builtins._("Enable debug mode with verbose output."),
         envvar="AQC_DEBUG"
     ),
     verbose: bool = typer.Option(
         False,
         "-v",
         "--verbose",
-        help=i18n._("Enable verbose output.")
+        help=builtins._("Enable verbose output.")
     )
 ):
     _ = builtins._
@@ -234,21 +276,43 @@ def main_callback(
                     pass
             full_help_text = help_output_capture.getvalue()
 
+            # Define aliases to filter out
+            aliases_to_filter = ["sim", "spl", "viz", "hea", "exo"]
+
             # Remove the gaia_message from the captured help text if it's present
             # This is to prevent duplication if Typer's help also includes it
-            gaia_message_raw = i18n._("Please note that the Gaia ESA Archive has been rolled back to version 3.7. Please find the release notes at https://www.cosmos.esa.int/web/gaia-users/archive/release-notes")
-            full_help_text = full_help_text.replace(gaia_message_raw + "\n", "") # Remove with newline
-            full_help_text = full_help_text.replace(gaia_message_raw, "") # Remove without newline
+            import re
+            full_help_text = re.sub(r"Please note that the Gaia ESA Archive has been rolled back to version 3\.7\..*?release-notes\)?\n?", "", full_help_text, flags=re.DOTALL)
 
             # Extract only the "Commands" section using regex, including the full bottom border
             commands_match = re.search(r'╭─ Commands ─.*?(\n(?:│.*?\n)*)╰─.*─╯', full_help_text, re.DOTALL)
             if commands_match:
                 commands_section = commands_match.group(0)
-                # This is a fallback in case Typer's internal help generation includes it
-                filtered_commands_section = "\n".join([
-                    line for line in commands_section.splitlines() if "Usage:" not in line
-                ])
-                console.print(filtered_commands_section)
+                # Filter out alias lines
+                filtered_commands_section_lines = []
+                for line in commands_section.splitlines():
+                    is_alias_line = False
+                    for alias in aliases_to_filter:
+                        # Check if the line starts with the alias name followed by spaces
+                        if re.match(rf"^\s*│\s*{re.escape(alias)}\s+", line):
+                            is_alias_line = True
+                            break
+                    if not is_alias_line and "Usage:" not in line:
+                        filtered_commands_section_lines.append(line)
+                
+                # Reconstruct the commands section, ensuring the borders are kept
+                if len(filtered_commands_section_lines) > 1: # Check if there's content beyond just the header/footer
+                    # Find the header and footer lines
+                    header_line = filtered_commands_section_lines[0]
+                    footer_line = filtered_commands_section_lines[-1]
+                    
+                    # Reconstruct the section with filtered content in between
+                    commands_section = header_line + "\n" + "\n".join(filtered_commands_section_lines[1:-1]) + "\n" + footer_line
+                else:
+                    # If only header/footer remain, just use the original filtered section
+                    commands_section = "\n".join(filtered_commands_section_lines)
+
+                console.print(commands_section)
             else:
                 # Fallback: if commands section not found, print full help
                 console.print(full_help_text)
@@ -262,7 +326,7 @@ def cli():
             debug_manager.enable_debug()
             # Print a message indicating debug mode is enabled
             console = Console()
-            console.print("[bold green]Debug mode enabled.[/bold green]")
+            console.print(_("[bold green]Debug mode enabled.[/bold green]"))
         # Removed the "Debug mode disabled" message as per user request.
 
         setup_subcommands()
