@@ -11,6 +11,7 @@ import re # Import re
 from io import StringIO # Import StringIO
 from contextlib import redirect_stdout # Import redirect_stdout
 from astroquery_cli.common_options import setup_debug_context # Import setup_debug_context
+from astroquery_cli.debug import debug # Import debug function
 
 def get_app():
     import builtins
@@ -155,18 +156,18 @@ def get_app():
 
         console.print(_("[cyan]Searching for VizieR catalogs...[/cyan]"))
         vizier_conf.server = VIZIER_SERVERS.get(vizier_server.lower(), vizier_conf.server)
-        console.print(_("[dim]Using VizieR server: {server_url}[/dim]").format(server_url=vizier_conf.server))
+        debug(_("Using VizieR server: {server_url}").format(server_url=vizier_conf.server))
 
         query_params = {}
         if keywords:
             query_params['keywords'] = keywords
-            console.print(_("[dim]Keywords: {keywords_list}[/dim]").format(keywords_list=keywords))
-        if ucd:
+            debug(_("Keywords: {keywords_list}").format(keywords_list=keywords))
+        if ucd is not None: # Only add if not None
             query_params['ucd'] = ucd
-            console.print(_("[dim]UCD: {ucd_val}[/dim]").format(ucd_val=ucd))
-        if source_name:
+            debug(_("UCD: {ucd_val}").format(ucd_val=ucd))
+        if source_name is not None: # Only add if not None
             query_params['source_name'] = source_name
-            console.print(_("[dim]Source Name: {source_val}[/dim]").format(source_val=source_name))
+            debug(_("Source Name: {source_val}").format(source_val=source_name))
 
         if not query_params:
             console.print(_("[yellow]Please provide at least one search criterion (keyword, ucd, or source name).[/yellow]"))
@@ -175,7 +176,7 @@ def get_app():
 
         try:
             result_tables = Vizier.find_catalogs(**query_params)
-            if result_tables:
+            if result_tables and len(result_tables) > 0 and 0 in result_tables.keys():
                 display_table(
                     ctx,
                     result_tables[0],
@@ -185,6 +186,7 @@ def get_app():
                 )
             else:
                 console.print(_("[yellow]No catalogs found matching your criteria.[/yellow]"))
+                return
 
         except Exception as e:
             handle_astroquery_exception(ctx, e, _("VizieR find_catalogs"))
@@ -195,6 +197,63 @@ def get_app():
             print(f"Elapsed: {elapsed:.3f} s")
             raise typer.Exit()
 
+    @app.command(
+        name="list",
+        help=builtins._(
+            "List all available VizieR catalogs. "
+            "Note: VizieR API does not support listing all catalogs at once. "
+            "If no catalogs are found, try 'find-catalogs' with keywords. "
+            "Common keywords: 'photometry', 'galaxy', 'quasar', 'gaia', '2mass', 'sdss', 'star', 'cluster', 'radio', 'infrared', 'xray', 'survey', 'variable', 'proper motion', 'catalog'. "
+            "Example: aqc vizier find-catalogs --keyword photometry --keyword galaxy"
+        )
+    )
+    @global_keyboard_interrupt_handler
+    def list_catalogs(ctx: typer.Context,
+        max_catalogs: int = typer.Option(20, help=builtins._("Maximum number of catalogs to list.")),
+        show_all_columns: bool = typer.Option(False, "--show-all-cols", help=builtins._("Show all columns in the output table.")),
+        vizier_server: str = typer.Option(
+            "vizier_cds",
+            help=builtins._("VizieR server to use. Choices: {server_list}").format(server_list=list(VIZIER_SERVERS.keys())),
+            autocompletion=lambda: list(VIZIER_SERVERS.keys())
+        )
+    ):
+        console.print(_("[cyan]Attempting to list all VizieR catalogs...[/cyan]"))
+        console.print(_("[yellow]Note: If this returns no catalogs, the VizieR service might not support listing all catalogs directly, or there might be a network issue. Consider using 'find-catalogs' with specific keywords instead.[/yellow]"))
+        vizier_conf.server = VIZIER_SERVERS.get(vizier_server.lower(), vizier_conf.server)
+        debug(_("Using VizieR server: {server_url}").format(server_url=vizier_conf.server))
+
+        try:
+            # Attempt to get all catalogs. If this fails or returns empty,
+            # we will fall back to a keyword search and provide suggestions.
+            all_catalogs = Vizier.get_catalogs(catalog=[])
+            
+            if all_catalogs:
+                display_table(
+                    ctx,
+                    all_catalogs[0],
+                    title=_("All Available VizieR Catalogs"),
+                    max_rows=max_catalogs,
+                    show_all_columns=show_all_columns
+                )
+            else:
+                console.print(_(
+                    "[yellow]No catalogs found using direct listing. "
+                    "VizieR API does not support listing all catalogs at once. "
+                    "Please use keyword search. "
+                    "Common keywords: 'photometry', 'galaxy', 'quasar', 'gaia', '2mass', 'sdss', 'star', 'cluster', 'radio', 'infrared', 'xray', 'survey', 'variable', 'proper motion', 'catalog'.[/yellow]"
+                ))
+                console.print(_("[yellow]Example: aqc vizier find-catalogs --keyword photometry --keyword galaxy[/yellow]"))
+                return
+
+        except Exception as e:
+            handle_astroquery_exception(ctx, e, _("VizieR list_catalogs"))
+            console.print(_(
+                "[yellow]VizieR API does not support listing all catalogs at once. "
+                "Please use keyword search. "
+                "Common keywords: 'photometry', 'galaxy', 'quasar', 'gaia', '2mass', 'sdss', 'star', 'cluster', 'radio', 'infrared', 'xray', 'survey', 'variable', 'proper motion', 'catalog'.[/yellow]"
+            ))
+            console.print(_("[yellow]Example: aqc vizier find-catalogs --keyword photometry --keyword galaxy[/yellow]"))
+            return
 
     @app.command(name="object", help=builtins._("Query catalogs around an object name or specific coordinates."))
     @global_keyboard_interrupt_handler
@@ -217,7 +276,7 @@ def get_app():
         console.print(_("[cyan]Querying VizieR for object '{target_name}' in catalog(s): {catalog_list}...[/cyan]").format(target_name=target, catalog_list=', '.join(catalogs_to_query)))
         vizier_conf.server = VIZIER_SERVERS.get(vizier_server.lower(), vizier_conf.server)
         vizier_conf.row_limit = row_limit
-        console.print(_("[dim]Using VizieR server: {server_url}, Row limit: {limit}[/dim]").format(server_url=vizier_conf.server, limit=row_limit))
+        debug(_("Using VizieR server: {server_url}, Row limit: {limit}").format(server_url=vizier_conf.server, limit=row_limit))
 
         coords = parse_coordinates(ctx, target)
         rad_quantity = parse_angle_str_to_quantity(ctx, radius)
@@ -272,7 +331,7 @@ def get_app():
         console.print(_(f"[cyan]Querying VizieR region around '{coordinates}' in catalog(s): {', '.join(catalogs_to_query)}...[/cyan]"))
         vizier_conf.server = VIZIER_SERVERS.get(vizier_server.lower(), vizier_conf.server)
         vizier_conf.row_limit = row_limit
-        console.print(_(f"[dim]Using VizieR server: {vizier_conf.server}, Row limit: {row_limit}[/dim]"))
+        debug(_(f"Using VizieR server: {vizier_conf.server}, Row limit: {row_limit}"))
 
         coords_obj = parse_coordinates(ctx, coordinates) # Changed to coords_obj
         rad_quantity = parse_angle_str_to_quantity(ctx, radius)
@@ -340,7 +399,7 @@ def get_app():
         console.print(_(f"[cyan]Querying VizieR with constraints in catalog(s): {', '.join(catalogs)}...[/cyan]"))
         vizier_conf.server = VIZIER_SERVERS.get(vizier_server.lower(), vizier_conf.server)
         vizier_conf.row_limit = row_limit
-        console.print(_(f"[dim]Using VizieR server: {vizier_conf.server}, Row limit: {row_limit}[/dim]"))
+        debug(_(f"Using VizieR server: {vizier_conf.server}, Row limit: {row_limit}"))
 
         parsed_constraints = parse_constraints_list(ctx, constraints)
         if not parsed_constraints and not keywords:
@@ -350,10 +409,10 @@ def get_app():
         query_kwargs = {}
         if parsed_constraints:
             query_kwargs.update(parsed_constraints)
-            console.print(_(f"[dim]Using constraints: {query_kwargs}[/dim]"))
+            debug(_(f"Using constraints: {query_kwargs}"))
         if keywords:
             query_kwargs['keywords'] = " ".join(keywords)
-            console.print(_(f"[dim]Using keywords: {query_kwargs['keywords']}[/dim]"))
+            debug(_(f"Using keywords: {query_kwargs['keywords']}"))
 
 
         viz = Vizier(columns=columns if columns else ["*"], row_limit=row_limit)
