@@ -12,6 +12,10 @@ DEFAULT_COMMANDS = [
     ["jplsbdb", "--help"],
     ["mast", "--help"],
     ["nasa-ads", "--help"],
+    ["heasarc", "--help"],
+    ["sdss", "--help"],
+    ["eso", "--help"],
+    ["nist", "--help"],
     ["ned", "--help"],
     ["simbad", "--help"],
     ["splatalogue", "--help"],
@@ -20,7 +24,7 @@ DEFAULT_COMMANDS = [
 
 def run_test(commands=None):
     """
-    commands: list of list, e.g. [["esasky", "list-catalogs"], ...]
+    commands: list of list, e.g. [["esasky", "object"], ...]
     If None, use DEFAULT_COMMANDS.
     """
     cli = [sys.executable, "-m", "astroquery_cli.main"]
